/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.activemq.artemis.core.paging.impl;

import org.apache.activemq.artemis.core.paging.PagingManager;
import org.apache.activemq.artemis.utils.SizeAwareMetric;

/** Use this class to access things that are meant on test only */
public class PagingManagerTestAccessor {

   public static void resetMaxSize(PagingManager pagingManager, long maxSize, long maxElements) {
      ((PagingManagerImpl)pagingManager).resetMaxSize(maxSize, maxElements);
   }

   public static SizeAwareMetric globalSizeAwareMetric(PagingManager pagingManager) {
      return ((PagingManagerImpl)pagingManager).getSizeAwareMetric();
   }

   public static String debugMessages(Page page) throws Exception {
      return page.debugMessages();
   }
}
